ecls_acad = read.table('C:\\GRE2016\\Data\\ecls_acad.dat', na.strings='.')

names(ecls_acad) = c('read1','math1','gk1','lrn_p1',
                     'read2','math2','gk2','lrn_p2')

head(ecls_acad)

#source('http://openmx.psyc.virginia.edu/getOpenMx.R')

library(OpenMx)

acad.omx <- mxModel('Example Model', 
    type='RAM', mxData(observed=ecls_acad, type='raw'), 
    manifestVars=c('read1','math1','gk1','read2','math2','gk2'),
    latentVars=c('eta_1','eta_2'), 

# Factor loadings
mxPath(from='eta_1', to=c('math1','read1','gk1'),
    arrows=1, free=c(FALSE,TRUE,TRUE), values=1, 
    labels=c(NA,'lambda_21','lambda_31')),

mxPath(from='eta_2', to=c('math2','read2','gk2'),
    arrows=1, free=c(FALSE,TRUE,TRUE), values=1, 
    labels=c(NA,'lambda_22','lambda_32')),

# Latent variable variances
mxPath(from=c('eta_1','eta_2'), 
    arrows=2, free=TRUE, values=c(60,10), labels=c('psi_11','psi_22')),

# Unique variances
mxPath(from=c('read1','math1','gk1','read2','math2','gk2'), 
    arrows=2, free=TRUE, values=30, 
    labels=c('theta_11','theta_22','theta_33','theta_44','theta_55','theta_66')),

# Unique covariances
mxPath(from=c('read1','math1','gk1'), to=c('read2','math2','gk2'), 
    arrows=2, free=TRUE, values=0, 
    labels=c('theta_41','theta_52','theta_63')),

# Latent variable regression
mxPath(from='eta_1', to='eta_2',
    arrows=1, free=TRUE, values=.8, 
    labels='beta_21'),

# means and intercepts 
mxPath(from='one', to=c('read1','math1','gk1','read2','math2','gk2'),  
    arrows=1, free=c(T,T,T,T,T,T), values=30,
    labels=c('tau_1','tau_2','tau_3','tau_4','tau_5','tau_6'))

) # close model

acad.fit = mxRun(acad.omx)

ref = mxRefModels(acad.fit, run=TRUE)

summary(acad.fit, refModels=ref)

#Summary of Example Model 
# 
#free parameters:
#        name matrix   row   col   Estimate   Std.Error A
#1  lambda_21      A read1 eta_1  0.8922588 0.008513840  
#2  lambda_31      A   gk1 eta_1  0.5748667 0.006343646  
#3    beta_21      A eta_2 eta_1  1.2237576 0.006964077  
#4  lambda_22      A read2 eta_2  0.9505533 0.009391106  
#5  lambda_32      A   gk2 eta_2  0.4702656 0.005253708  
#6   theta_11      S read1 read1 44.8938868 0.638176946  
#7   theta_22      S math1 math1  7.8867219 0.506527060 *
#8   theta_33      S   gk1   gk1 32.4470291 0.383090959  
#9   theta_41      S read1 read2 43.1133738 0.748750590  
#10  theta_44      S read2 read2 88.5639343 1.115438278  
#11  theta_52      S math1 math2 -0.5698243 0.512431264 *
#12  theta_55      S math2 math2 20.9572064 0.931649836  
#13  theta_63      S   gk1   gk2 26.2021097 0.346362736  
#14  theta_66      S   gk2   gk2 34.3432551 0.391361917  
#15    psi_11      S eta_1 eta_1 74.5752400 0.954203915  
#16    psi_22      S eta_2 eta_2 11.6487048 0.376776831  
#17     tau_1      M     1 read1 34.7910987 0.073164374  
#18     tau_2      M     1 math1 25.8211151 0.064235315  
#19     tau_3      M     1   gk1 21.7612556 0.054261725  
#20     tau_4      M     1 read2 45.9535899 0.100278272  
#21     tau_5      M     1 math2 36.1308944 0.084338896  
#22     tau_6      M     1   gk2 26.8106199 0.055769635  
#
#observed statistics:  111311 
#estimated parameters:  22 
#degrees of freedom:  111289 
#fit value ( -2lnL units ):  735419 
#saturated fit value ( -2lnL units ):  735149 
#number of observations:  20601 
#chi-square:  X2 ( df=5 ) = 270.0144,  p = 2.778631e-56
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:       512841.0               735463.0                       NA
#BIC:      -370025.2               735637.6                 735567.6
#CFI: 0.9971029 
#TLI: 0.9913086   (also known as NNFI) 
#RMSEA:  0.05072308  [95% CI (0.04468658, 0.05694658)]
#Prob(RMSEA <= 0.05): 0.3967836
#OpenMx does not recommend using GFI, AGFI, NFI (aka Bentler-Bonett), or SRMR:
# See help(mxSummary) for why. 
#timestamp: 2016-01-11 20:58:05 
#Wall clock time (HH:MM:SS.hh): 00:00:34.02 
#OpenMx version number: 2.2.4 
#Need help?  See help(mxSummary) 

mxStandardizeRAMpaths(acad.fit,SE=FALSE)

#                   name     label matrix   row   col  Raw.Value        Raw.SE    Std.Value        Std.SE
#1  Example Model.A[1,7] lambda_21      A read1 eta_1  0.8922588 not requested  0.754603065 not requested
#2  Example Model.A[2,7]      <NA>      A math1 eta_1  1.0000000 not requested  0.950978062 not requested
#3  Example Model.A[3,7] lambda_31      A   gk1 eta_1  0.5748667 not requested  0.657017150 not requested
#4  Example Model.A[8,7]   beta_21      A eta_2 eta_1  1.2237576 not requested  0.951603635 not requested
#5  Example Model.A[4,8] lambda_22      A read2 eta_2  0.9505533 not requested  0.746445305 not requested
#6  Example Model.A[5,8]      <NA>      A math2 eta_2  1.0000000 not requested  0.924529521 not requested
#7  Example Model.A[6,8] lambda_32      A   gk2 eta_2  0.4702656 not requested  0.665313422 not requested
#8  Example Model.S[1,1]  theta_11      S read1 read1 44.8938868 not requested  0.430574214 not requested
#9  Example Model.S[4,1]  theta_41      S read2 read1 43.1133738 not requested  0.298557020 not requested
#10 Example Model.S[2,2]  theta_22      S math1 math1  7.8867219 not requested  0.095640726 not requested
#11 Example Model.S[5,2]  theta_52      S math2 math1 -0.5698243 not requested -0.005223941 not requested
#12 Example Model.S[3,3]  theta_33      S   gk1   gk1 32.4470291 not requested  0.568328464 not requested
#13 Example Model.S[6,3]  theta_63      S   gk2   gk1 26.2021097 not requested  0.441768664 not requested
#14 Example Model.S[4,4]  theta_44      S read2 read2 88.5639343 not requested  0.442819407 not requested
#15 Example Model.S[5,5]  theta_55      S math2 math2 20.9572064 not requested  0.145245164 not requested
#16 Example Model.S[6,6]  theta_66      S   gk2   gk2 34.3432551 not requested  0.557358050 not requested
#17 Example Model.S[7,7]    psi_11      S eta_1 eta_1 74.5752400 not requested  1.000000000 not requested
#18 Example Model.S[8,8]    psi_22      S eta_2 eta_2 11.6487048 not requested  0.094450522 not requested
